import 'package:ui_sdk/props/ApiResponse.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ui_sdk/props/StandardScreenResponse.dart';


class StandardScreenResponseCubit extends Cubit<Map<String, StandardScreenResponse?>> {
  StandardScreenResponseCubit() : super({});

  void updateStandardScreenResponse(String screenReference, StandardScreenResponse standardScreenResponse) {
    final updatedMap = Map<String, StandardScreenResponse?>.from(state);
    updatedMap[screenReference] = standardScreenResponse;
    emit(updatedMap);
  }
}


enum RequestState { initial, loading, loaded, error }

class ApiResponseState {
  final RequestState responseState;
  final bool isPullToRefreshEnabled;
  final Map<String, StandardScreenResponse?> standardScreenResponseMap;
  final ApiResponse? apiResponse;

  ApiResponseState({
    required this.responseState,
    this.isPullToRefreshEnabled = false,
    Map<String, StandardScreenResponse?>? standardScreenResponseMap,
    this.apiResponse,
  }) : standardScreenResponseMap = standardScreenResponseMap ?? {};
}

class ApiResponseCubit extends Cubit<ApiResponseState> {
  final StandardScreenResponseCubit standardScreenResponseCubit;

  ApiResponseCubit(this.standardScreenResponseCubit) : super(ApiResponseState(responseState: RequestState.initial));

  void fetchData(Future<ApiResponse> Function(Map<dynamic, dynamic>) fetchDataFunction, Map<dynamic, dynamic> args, String screenReference) async {
    emit(ApiResponseState(responseState: RequestState.loading));
    try {
      final result = await fetchDataFunction(args);
      StandardScreenResponse standardScreenResponse = StandardScreenResponse.fromJson(result.data);
      bool pullToRefresh = _isPullToRefreshEnabled(standardScreenResponse);

      standardScreenResponseCubit.updateStandardScreenResponse(screenReference, standardScreenResponse);

      emit(ApiResponseState(
        responseState: RequestState.loaded,
        isPullToRefreshEnabled: pullToRefresh,
        apiResponse: result,
      ));
    } catch (e) {
      emit(ApiResponseState(responseState: RequestState.error));
    }
  }


  bool _isPullToRefreshEnabled(StandardScreenResponse? standardScreenResponse) {
    try {
      if (standardScreenResponse != null &&
          standardScreenResponse.pageState != null &&
          standardScreenResponse.pageState!.containsKey('enablePullToRefresh') &&
          standardScreenResponse.pageState!['enablePullToRefresh'] == true) {
        return true;
      } else {
        return false;
      }
    } catch(e){
      return false;
    }
  }
}
