import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikAvatar.dart';
import 'package:ui_sdk/components/UikRow.dart';
import 'package:ui_sdk/components/UikText.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/generated/json/base/json_convert_content.dart';
import 'package:ui_sdk/props/UikCardProps.dart';
import 'package:ui_sdk/getWidgets/uikButtonBar/UikButtonBar.dart';
import 'package:ui_sdk/getWidgets/uikButtonBar/UikButtonBarProps.dart';
import 'package:ui_sdk/getWidgets/uikImageOverlay/UikImageOverlay.dart';
import 'package:ui_sdk/getWidgets/uikImageOverlay/UikImageOverlayProps.dart';
import 'package:ui_sdk/getWidgets/uikListTile/UikGWListTile.dart';
import 'package:ui_sdk/getWidgets/uikListTile/UikGWListTileProps.dart';
import 'package:ui_sdk/getWidgets/uikPosition/UikPositon.dart';
import 'package:ui_sdk/props/UikTextProps.dart';
import 'package:ui_sdk/utils/extensions.dart';

import '../../components/UikListTile.dart';
import '../../props/UikAvatarProps.dart';
import '../../props/UikListTileProps.dart';
import '../../props/UikRowProps.dart';

UikCardProps $UikCardPropsFromJson(Map<String, dynamic> json) {
  UikCardProps uikCardProps = UikCardProps();
  final String? id = jsonConvert.convert<String>(json['id']);
  if (id != null) {
    uikCardProps.id = id;
  }
  final String? color = jsonConvert.convert<String>(json['color']);
  if (color != null) {
    uikCardProps.color = color.toColor();
  }
  final double? height = jsonConvert.convert(json['height']);
  if (height != null) {
    uikCardProps.height = height;
  }
  final double? elevation = jsonConvert.convert(json["elevation"]);
  if (elevation != null) {
    uikCardProps.elevation = elevation;
  }
  final String? titlePosition =
      jsonConvert.convert<String>(json['titlePosition']);
  if (titlePosition != null) {
    if (titlePosition == 'start') {
      uikCardProps.titlePosition = UikPosition.start;
    } else {
      uikCardProps.titlePosition = UikPosition.end;
    }
  }
  final String? shape = jsonConvert.convert<String>(json['shape']);
  if (shape != null) {
    uikCardProps.shape = RoundedRectangleBorder(
      borderRadius: BorderRadius.all(Radius.circular(8)),
    );
  }
  final String? clipBehavior =
      jsonConvert.convert<String>(json['clipBehavior']);
  if (clipBehavior != null) {
    if (clipBehavior == 'antiAliasWithSaveLayer') {
      uikCardProps.clipBehavior = Clip.antiAliasWithSaveLayer;
    } else if (clipBehavior == 'antiAlias') {
      uikCardProps.clipBehavior = Clip.antiAlias;
    } else if (clipBehavior == 'hardEdge') {
      uikCardProps.clipBehavior = Clip.hardEdge;
    } else {
      uikCardProps.clipBehavior = Clip.none;
    }
  }
  final double? margin = jsonConvert.convert(json['margin']);
  if (margin != null) {
    uikCardProps.margin = EdgeInsets.symmetric(
      horizontal: margin,
      vertical: margin,
    );
  }
  final double? padding = jsonConvert.convert(json['padding']);
  if (padding != null) {
    uikCardProps.padding = EdgeInsets.symmetric(
      horizontal: padding,
      vertical: padding,
    );
  }
  final String? content = jsonConvert.convert<String>(json['content']);
  final String? contentType = jsonConvert.convert(json['contentType']);
  if (content != null) {
    if (contentType == 'text') {
      uikCardProps.content = UikText(
        WidgetType.UikText,
        UikTextProps.fromJson(
          json['content'],
        ),
      );
    } else if (contentType == "list") {
      uikCardProps.content = Column(
        children: _getListOfWidgets(json['content']),
      );
    }
  }
  final String? title = jsonConvert.convert<String>(json['title']);
  if (title != null) {
    uikCardProps.title = UikGWListTile(
      WidgetType.UikGWListTile,
      UikGWListTileProps.fromJson(json['title']),
    );
  }
  final bool? borderOnForeground =
      jsonConvert.convert(json['borderOnForeground']);
  if (borderOnForeground != null) {
    uikCardProps.borderOnForeground = borderOnForeground;
  }
  final bool? showImage = jsonConvert.convert(json['showImage']);
  if (showImage != null) {
    uikCardProps.showImage = showImage;
  }
  final bool? showOverlayImage = jsonConvert.convert(json['showOverlayImage']);
  if (showOverlayImage != null) {
    uikCardProps.showOverlayImage = showOverlayImage;
  }
  final String? image = jsonConvert.convert<String>(json['image']);
  if (image != null) {
    uikCardProps.image = Image(
      image: NetworkImage(image),
      fit: BoxFit.fitWidth,
    );
  }
  // final String? imageOverlay =
  //     jsonConvert.convert<String>(json['imageOverlay']);
  // if (imageOverlay != null) {
  //   uikCardProps.imageOverlay = NetworkImage(imageOverlay);
  // }
  final String? buttonBar = jsonConvert.convert(json['buttonBar']);
  if (buttonBar != null) {
    uikCardProps.buttonBar = UikButtonBar(
        WidgetType.UikButtonBar, UikButtonBarProps.fromJson(json['buttonBar']));
  }
  final double? borderRadius = jsonConvert.convert(json['borderRadius']);
  if (borderRadius != null) {
    uikCardProps.borderRadius = BorderRadius.all(Radius.circular(borderRadius));
  }
  // final String? border = jsonConvert.convert<String>(json['border']);
  // if (border != null) {
  //   uikCardProps.border = Border();
  // }
  final List<String>? gradient = jsonConvert.convert(json['gradient']);
  if (gradient != null) {
    List<Color> colors = [];
    for (var color = 0; color < gradient.length; color++) {
      colors.add(gradient[color].toColor());
    }

    uikCardProps.gradient = LinearGradient(colors: colors);
  }
  final String? overlayImage = jsonConvert.convert(json['overlayImage']);
  if (overlayImage != null) {
    uikCardProps.overlayImage = UikImageOverlay(WidgetType.UikImageOverlay,
        UikImageOverlayProps.fromJson(json['overlayImage']));
  }

  return uikCardProps;
}

List<Widget> _getListOfWidgets(List<dynamic> widgets) {
  List<Widget> widgetList = [];
  for (dynamic widget in widgets) {
    if (widget["id"] == "UikListTile") {
      Widget wid =
          UikListTile(WidgetType.UikCard, UikListTileProps.fromJson(widget));
      widgetList.add(wid);
    } else if (widget["id"] == "UikRow") {
      Widget wid = UikRow(WidgetType.UikRow, UikRowProps.fromJson(widget));
      // Widget wid = _getProfileWidget(widget);
      widgetList.add(wid);
      // debugPrint("widgetlist length: ${widgetList.length}");
    }
  }

  return widgetList;
}
