import 'package:flutter/cupertino.dart';
import 'package:ui_sdk/components/UikAvatar.dart';
import 'package:ui_sdk/components/UikButton.dart';
import 'package:ui_sdk/components/UikCell.dart';
import 'package:ui_sdk/components/UikContainerText.dart';
import 'package:ui_sdk/components/UikIconText.dart';
import 'package:ui_sdk/components/UikImage.dart';
import 'package:ui_sdk/components/UikRow.dart';
import 'package:ui_sdk/components/UikText.dart';
import 'package:ui_sdk/components/UikTwoComponentRow.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/generated/json/base/json_convert_content.dart';
import 'package:ui_sdk/props/UikAvatarProps.dart';
import 'package:ui_sdk/props/UikButtonProps.dart';
import 'package:ui_sdk/props/UikCellProps.dart';
import 'package:ui_sdk/props/UikContainerTextProps.dart';
import 'package:ui_sdk/props/UikIconProps.dart';
import 'package:ui_sdk/props/UikIconTextProps.dart';
import 'package:ui_sdk/props/UikImageProps.dart';
import 'package:ui_sdk/props/UikRowProps.dart';
import 'package:ui_sdk/props/UikTwoComponentRowProps.dart';
import 'package:ui_sdk/utils/UiSdkUtils.dart';

import '../../components/UikIcon.dart';
import '../../props/UikColumnProps.dart';
import '../../props/UikSimpleColumnProps.dart';
import '../../props/UikTextProps.dart';

UikSimpleColumnProps $UikSimpleColumnPropsFromJson(Map<String, dynamic> json) {
  final UikSimpleColumnProps uikColumnProps = UikSimpleColumnProps();
  final String? id = jsonConvert.convert<String>(json['id']);
  if (id != null) {
    uikColumnProps.id = id;
  }

  String? mainAxisAlignment =
      jsonConvert.convert<String?>(json["mainAxisAlignment"]);
  if (mainAxisAlignment != null) {
    uikColumnProps.mainAxisAlignment = getMainAxisAlignment(mainAxisAlignment);
  }

  String? crossAxisAlignment =
      jsonConvert.convert<String?>(json["crossAxisAlignment"]);
  if (crossAxisAlignment != null) {
    uikColumnProps.crossAxisAlignment =
        getCrossAxisAlignment(crossAxisAlignment);
  }
  String? alignment = jsonConvert.convert<String?>(json["alignment"]);
  if (alignment != null) {
    switch (alignment) {
      case 'bottomCenter':
        uikColumnProps.alignment = Alignment.bottomCenter;
        break;
      case 'bottomLeft':
        uikColumnProps.alignment = Alignment.bottomLeft;
        break;
      case 'bottomRight':
        uikColumnProps.alignment = Alignment.bottomRight;
        break;
      case 'center':
        uikColumnProps.alignment = Alignment.center;
        break;
      case 'centerLeft':
        uikColumnProps.alignment = Alignment.centerLeft;
        break;
      case 'centerRight':
        uikColumnProps.alignment = Alignment.centerRight;
        break;
      case 'topCenter':
        uikColumnProps.alignment = Alignment.topCenter;
        break;
      case 'topLeft':
        uikColumnProps.alignment = Alignment.topLeft;
        break;
      case 'topRight':
        uikColumnProps.alignment = Alignment.topRight;
        break;
    }
  }

  final List<dynamic>? widgets =
      jsonConvert.convert<List<dynamic>>(json["widgets"]);
  if (widgets != null) {
    for (int i = 0; i < widgets.length; i++) {
      if (widgets[i]["id"] == "image") {
        uikColumnProps.widgets.add(UikImage(
            WidgetType.UikImage, UikImageProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "text") {
        uikColumnProps.widgets.add(UikContainerText(WidgetType.UikText,
            UikContainerTextProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "avatar") {
        // UiSdkUtils.prettyPrintJson(widgets[i]);

        uikColumnProps.widgets.add(UikAvatar(
            WidgetType.UikAvatar, UikAvatarProps.fromJson(json["widgets"][i])));
      }
      if (widgets[i]["id"] == "icon") {
        uikColumnProps.widgets.add(UikIcon(
            WidgetType.UikText, UikIconProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "text1") {
        // UiSdkUtils.prettyPrintJson(widgets[i]);

        uikColumnProps.widgets.add(UikText(
            WidgetType.UikText, UikTextProps.fromJson(json["widgets"][i])));
      }
      if (widgets[i]["id"] == "txt") {
        uikColumnProps.widgets.add(UikText(
            WidgetType.UikText, UikTextProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "cell") {
        uikColumnProps.widgets.add(UikCell(
            WidgetType.UikText, UikCellProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "itext") {
        uikColumnProps.widgets.add(UikIconText(
            WidgetType.UikText, UikIconTextProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "button") {
        uikColumnProps.widgets.add(UikButton(
            WidgetType.UikText, UikButtonProps.fromJson(json["widgets"][i])));
      }

      if (widgets[i]["id"] == "twoRow") {
        uikColumnProps.widgets.add(UikTwoComponentRow(WidgetType.UikText,
            UikTwoComponentRowProps.fromJson(json["widgets"][i])));
      }
      if (widgets[i]["id"] == "UikRow") {
        // UiSdkUtils.prettyPrintJson(widgets[i]);

        uikColumnProps.widgets.add(UikRow(
            WidgetType.UikRow, UikRowProps.fromJson(json["widgets"][i])));
      }
    }
  }

  final double? leftMargin = jsonConvert.convert<double>(json["leftMargin"]);
  if (leftMargin != null) {
    uikColumnProps.leftMargin = leftMargin;
  }

  final double? height = jsonConvert.convert<double>(json["height"]);
  if (height != null) {
    uikColumnProps.height = height;
  }

  final double? rightMargin = jsonConvert.convert<double>(json["rightMargin"]);
  if (rightMargin != null) {
    uikColumnProps.rightMargin = rightMargin;
  }

  final double? topMargin = jsonConvert.convert<double>(json["topMargin"]);
  if (topMargin != null) {
    uikColumnProps.topMargin = topMargin;
  }

  final double? bottomMargin =
      jsonConvert.convert<double>(json["bottomMargin"]);
  if (bottomMargin != null) {
    uikColumnProps.bottomMargin = bottomMargin;
  }

  return uikColumnProps;
}

Map<String, dynamic> $UikSimpleColumnPropsToJson(UikSimpleColumnProps entity) {
  final Map<String, dynamic> data = <String, dynamic>{};
  data['id'] = entity.id;
  // data['src'] = entity.src;
  // data['action'] = entity.action.toJson();
  return data;
}

MainAxisAlignment getMainAxisAlignment(String alignemnt) {
  switch (alignemnt) {
    case 'center':
      return MainAxisAlignment.center;
    case 'start':
      return MainAxisAlignment.start;
    case 'end':
      return MainAxisAlignment.end;
    case 'spaceAround':
      return MainAxisAlignment.spaceAround;
    case 'spaceBetween':
      return MainAxisAlignment.spaceBetween;
    case 'spaceEvenly':
      return MainAxisAlignment.spaceEvenly;
    default:
      return MainAxisAlignment.start;
  }
}

CrossAxisAlignment getCrossAxisAlignment(String alignemnt) {
  switch (alignemnt) {
    case 'center':
      return CrossAxisAlignment.center;
    case 'start':
      return CrossAxisAlignment.start;
    case 'end':
      return CrossAxisAlignment.end;
    case 'stretch':
      return CrossAxisAlignment.stretch;
    case 'baseline':
      return CrossAxisAlignment.baseline;
    default:
      return CrossAxisAlignment.center;
  }
}
