import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:provider/provider.dart';
import 'package:ui_sdk/NavigatorService.dart';
import 'package:ui_sdk/StandardPage.dart';
import 'package:ui_sdk/props/ApiResponse.dart';
import 'package:ui_sdk/props/UikAction.dart';
import 'package:ui_sdk/utils/update_ui_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'ApiResponseState.dart';

void main() async {
  runApp(
    MultiBlocProvider(
      providers: [
        BlocProvider<StandardScreenResponseCubit>(
          create: (context) => StandardScreenResponseCubit(),
        ),
        BlocProvider<ApiResponseCubit>(
          create: (context) => ApiResponseCubit(
            BlocProvider.of<StandardScreenResponseCubit>(context),
          ),
        ),
      ],
      child: const MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  static final GlobalKey<NavigatorState> navigatorKey =
      GlobalKey<NavigatorState>();
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => UpdateUIProvider(),
      child: MaterialApp(
        debugShowCheckedModeBanner: false,
        home: HomePage().page,
      ),
    );
  }
  // @override
  // Widget build(BuildContext context) {
  //   return ChangeNotifierProvider(
  //     create: (context) => UpdateUIProvider(),
  //     child: MaterialApp(
  //       home: HomePage().page,
  //     ),
  //   );
  // }
}

class HomePage extends StandardPage {
  @override
  dynamic getData() {
    return fetchAlbum;
  }

  @override
  Set<String?> getActions() {
    Set<String?> actionList = {};
    actionList.add("OPEN_WEB");
    actionList.add("OPEN_ROUTE");
    actionList.add("ADD_TO_CART");
    actionList.add("OPEN_CATEGORY");
    actionList.add("UPDATE_UI");
    actionList.add("OPEN_PRODUCT");
    actionList.add("ON_TEXT_EDIT_COMPLETE");
    actionList.add("SELECT_STATE");
    return actionList;
  }

  @override
  getPageCallBackForAction() {
    return of;
  }

  void of(UikAction uikAction) {
    var context = NavigationService.navigatorKey.currentContext;
    String type = uikAction.tap.type;
    switch (type) {
      case "OPEN_WEB":
        {
          if (uikAction.tap.values != null) {
            print(uikAction.tap.values!["state"]);
          }
        }
        break;
      case "OPEN_ROUTE":
        {
          print("inside the case of open route");
        }
        break;
      case "OPEN_CATEGORY":
        {
          Navigator.pushNamed(
            context!,
            '/test',
            arguments: 82,
          );
          print("Inside OPEN_CATEGORY");

          getData();
        }
        break;
      case "UPDATE_UI":
        {
          print("Inside UPDATE_UI");
          // var context = NavigationService.navigatorKey.currentContext!;
          // Provider.of<UpdateUIProvider>(context, listen: false).updateUI();
        }
        break;
      case "ON_TEXT_EDIT_COMPLETE":
        {
          print("Inside ON_TEXT_EDIT_COMPLETE");
        }
        break;
      case "OPEN_PRODUCT":
        {
          print("Inside OPEN_PRODUCT");
        }
        break;
      case "SELECT_STATE":
        {
          print("Inside SELECT_STATE");
        }
        break;
      default:
        {
          print("default switch case :(");
        }
        break;
    }
  }

  @override
  getPageContext() {
    return "HomePage";
  }

  @override
  getConstructorArgs() {
    // TODO: implement getConstructorArgs
    return {};
  }
}

Future<ApiResponse> fetchAlbum(args) async {
  final queryParameter = {
    "id": "eb5f37b2-ca34-40a1-83ba-cb161eb55e6e",
  };
//http://demo5462168.mockable.io/landingScreenPartner
  final response = await http.get(
    Uri.parse('http://demo1043773.mockable.io/orderDetails'),
    headers: {
      "ngrok-skip-browser-warning": "value",
    },
  );

  if (response.statusCode == 200) {
    return ApiResponse.fromJson(jsonDecode(response.body));
  } else {
    throw Exception('Failed to load album');
  }
}
